==> yak_widgets-0.2.0%2B0.tar.gz: lib/src/ui/widget/sidebar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import '../../../yak_widgets.dart';

/// a ready to use widget that changes `sidebarPod` state

class YakSidebar extends HookWidget {
  /// allow to change `scrollSensitivity` to a custom value; default `1%`
  final double scrollSensitivity;

  /// allow to change `width` to a custom value; default `54`
  final double width;

  /// you may provide a `child` althogh is not required
  final Widget child;

  /// `YakSidebar` does not require any
  const YakSidebar({
    required this.child,
    this.scrollSensitivity = .01,
    this.width = 54,
    Key key = const ValueKey('YakSidebar'),
  })
  // coverage:ignore-line
  : super(key: key);

  @override
  Widget build(BuildContext context) {
    final scroll = useProvider(sidebarPod);
    final height = MediaQuery.of(context).size.height;
    final threshold = height * scrollSensitivity;
    return YakHandedness(
      child: SizedBox(
        key: ValueKey('$key: SizedBox'),
        height: height,
        width: width,
        child: GestureDetector(
          key: ValueKey('$key: GestureDetector'),
          onVerticalDragUpdate: (details) {
            if (details.delta.dy.abs() > threshold &&
                details.delta.dx < threshold) {
              details.delta.dy < 0
                  ? scroll.state = SidebarScroll.up
                  : scroll.state = SidebarScroll.down;
            }
          },
          child: child,
        ),
      ),
    );
  }
}

==> yak_widgets-0.3.0%2B0.tar.gz: lib/src/ui/widget/sidebar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import '../../../yak_widgets.dart';

/// a ready to use widget that changes `sidebarPod` state

class Sidebar extends HookWidget {
  /// allow to change `scrollSensitivity` to a custom value; default `1%`
  final double scrollSensitivity;

  /// allow to change `width` to a custom value; default `54`
  final double width;

  /// you may provide a `child` althogh is not required
  final Widget child;

  /// `YakSidebar` does not require any
  const Sidebar({
    required this.child,
    this.scrollSensitivity = .01,
    this.width = 54,
    Key key = const ValueKey('YakSidebar'),
  })
  // coverage:ignore-line
  : super(key: key);

  @override
  Widget build(BuildContext context) {
    final scroll = useProvider(sidebarPod);
    final height = MediaQuery.of(context).size.height;
    final threshold = height * scrollSensitivity;
    return Handedness(
      child: SizedBox(
        key: ValueKey('$key@SizedBox'),
        height: height,
        width: width,
        child: GestureDetector(
          key: ValueKey('$key@GestureDetector'),
          onVerticalDragUpdate: (details) {
            if (details.delta.dy.abs() > threshold &&
                details.delta.dx < threshold) {
              details.delta.dy < 0
                  ? scroll.state = SidebarScroll.up
                  : scroll.state = SidebarScroll.down;
            }
          },
          child: child,
        ),
      ),
    );
  }
}
